@@ -1,6 +1,6 @@
 package Archive::Tar::Builder;
 
-# Copyright (c) 2025, cPanel, L.L.C.
+# Copyright (c) 2014, cPanel, Inc.
 # All rights reserved.
 # http://cpanel.net/
 #
@@ -12,10 +12,9 @@ use warnings;
 
 use XSLoader ();
 
-use Archive::Tar::Builder::UserCache     ();
-use Archive::Tar::Builder::HardlinkCache ();
+use Archive::Tar::Builder::UserCache ();
 
-our $VERSION = '2.5006_0001';
+our $VERSION = '2.5000';
 
 XSLoader::load( 'Archive::Tar::Builder', $VERSION );
 
@@ -71,20 +70,11 @@ cause Archive::Tar::Builder to die() at the end of the stream.
 
 When set, symlinks encountered while archiving are followed.
 
-=item C<preserve_hardlinks>
-
-When set, hardlinks encountered while archiving are preserved, and their
-respective file contents will not be duplicated in the output stream.
-
 =item C<gnu_extensions>
 
 When set, support for arbitrarily long pathnames is enabled using the GNU
 LongLink format.
 
-=item C<posix_extensions>
-
-When set, PAX format archives will be streamed.
-
 =back
 
 =back
@@ -196,7 +186,7 @@ C<ignore_errors> is not enabled.  Finally, reset any other error data present.
 
 =head1 AUTHOR
 
-Written by Alexandra Hrefna Maheu <xan@cpan.org>
+Written by Xan Tronix <xan@cpan.org>
 
 =head1 CONTRIBUTORS
 
@@ -210,7 +200,7 @@ Written by Alexandra Hrefna Maheu <xan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2019, cPanel, L.L.C.
+Copyright (c) 2014, cPanel, Inc.
 All rights reserved.
 http://cpanel.net/
 
